@@ -65,7 +65,6 @@ const (
 	MetadataDependency                  = "dependency"
 	MetadataDownloadDir                 = "download_dir"
 	MetadataPreventDestroy              = "prevent_destroy"
-	MetadataSkip                        = "skip"
 	MetadataIamRole                     = "iam_role"
 	MetadataIamAssumeRoleDuration       = "iam_assume_role_duration"
 	MetadataIamAssumeRoleSessionName    = "iam_assume_role_session_name"
@@ -76,9 +75,6 @@ const (
 	MetadataCatalog                     = "catalog"
 	MetadataEngine                      = "engine"
 	MetadataGenerateConfigs             = "generate"
-	MetadataRetryableErrors             = "retryable_errors"
-	MetadataRetryMaxAttempts            = "retry_max_attempts"
-	MetadataRetrySleepIntervalSec       = "retry_sleep_interval_sec"
 	MetadataDependentModules            = "dependent_modules"
 	MetadataInclude                     = "include"
 	MetadataFeatureFlag                 = "feature"
@@ -143,7 +139,6 @@ type DecodedBaseBlocks struct {
 type TerragruntConfig struct {
 	Locals                      map[string]any
 	ProcessedIncludes           IncludeConfigsMap
-	RetryMaxAttempts            *int
 	FieldsMetadata              map[string]map[string]any
 	Terraform                   *TerraformConfig
 	Errors                      *ErrorsConfig
@@ -151,10 +146,8 @@ type TerragruntConfig struct {
 	Dependencies                *ModuleDependencies
 	Exclude                     *ExcludeConfig
 	PreventDestroy              *bool
-	Skip                        *bool
 	GenerateConfigs             map[string]codegen.GenerateConfig
 	IamAssumeRoleDuration       *int64
-	RetrySleepIntervalSec       *int
 	Inputs                      map[string]any
 	Engine                      *EngineConfig
 	Catalog                     *CatalogConfig
@@ -166,7 +159,6 @@ type TerragruntConfig struct {
 	TerraformVersionConstraint  string
 	TerraformBinary             string
 	TerragruntDependencies      Dependencies
-	RetryableErrors             []string
 	FeatureFlags                FeatureFlags
 	DependentModulesPath        []*string
 	IsPartial                   bool
@@ -610,10 +602,6 @@ func (cfg *TerragruntConfig) WriteTo(w io.Writer) (int64, error) {
 		rootBody.SetAttributeValue("prevent_destroy", cfgAsCty.GetAttr("prevent_destroy"))
 	}
 
-	if cfg.Skip != nil {
-		rootBody.SetAttributeValue("skip", cfgAsCty.GetAttr("skip"))
-	}
-
 	if cfg.IamRole != "" {
 		rootBody.SetAttributeValue("iam_role", cfgAsCty.GetAttr("iam_role"))
 	}
@@ -626,18 +614,6 @@ func (cfg *TerragruntConfig) WriteTo(w io.Writer) (int64, error) {
 		rootBody.SetAttributeValue("iam_assume_role_session_name", cfgAsCty.GetAttr("iam_assume_role_session_name"))
 	}
 
-	if cfg.RetryMaxAttempts != nil {
-		rootBody.SetAttributeValue("retry_max_attempts", cfgAsCty.GetAttr("retry_max_attempts"))
-	}
-
-	if cfg.RetrySleepIntervalSec != nil {
-		rootBody.SetAttributeValue("retry_sleep_interval_sec", cfgAsCty.GetAttr("retry_sleep_interval_sec"))
-	}
-
-	if len(cfg.RetryableErrors) > 0 {
-		rootBody.SetAttributeValue("retryable_errors", cfgAsCty.GetAttr("retryable_errors"))
-	}
-
 	if len(cfg.Inputs) > 0 {
 		rootBody.SetAttributeValue("inputs", cfgAsCty.GetAttr("inputs"))
 	}
@@ -675,7 +651,6 @@ type terragruntConfigFile struct {
 	Dependencies             *ModuleDependencies `hcl:"dependencies,block"`
 	DownloadDir              *string             `hcl:"download_dir,attr"`
 	PreventDestroy           *bool               `hcl:"prevent_destroy,attr"`
-	Skip                     *bool               `hcl:"skip,attr"`
 	IamRole                  *string             `hcl:"iam_role,attr"`
 	IamAssumeRoleDuration    *int64              `hcl:"iam_assume_role_duration,attr"`
 	IamAssumeRoleSessionName *string             `hcl:"iam_assume_role_session_name,attr"`
@@ -703,10 +678,6 @@ type terragruntConfigFile struct {
 	GenerateAttrs  *cty.Value                `hcl:"generate,optional"`
 	GenerateBlocks []terragruntGenerateBlock `hcl:"generate,block"`
 
-	RetryableErrors       []string `hcl:"retryable_errors,optional"`
-	RetryMaxAttempts      *int     `hcl:"retry_max_attempts,optional"`
-	RetrySleepIntervalSec *int     `hcl:"retry_sleep_interval_sec,optional"`
-
 	// This struct is used for validating and parsing the entire terragrunt config. Since locals and include are
 	// evaluated in a completely separate cycle, it should not be evaluated here. Otherwise, we can't support self
 	// referencing other elements in the same block.
@@ -1672,21 +1643,6 @@ func convertToTerragruntConfig(ctx *ParsingContext, configPath string, terragrun
 		terragruntConfig.SetFieldMetadata(MetadataTerraformBinary, defaultMetadata)
 	}
 
-	if terragruntConfigFromFile.RetryableErrors != nil {
-		terragruntConfig.RetryableErrors = terragruntConfigFromFile.RetryableErrors
-		terragruntConfig.SetFieldMetadata(MetadataRetryableErrors, defaultMetadata)
-	}
-
-	if terragruntConfigFromFile.RetryMaxAttempts != nil {
-		terragruntConfig.RetryMaxAttempts = terragruntConfigFromFile.RetryMaxAttempts
-		terragruntConfig.SetFieldMetadata(MetadataRetryMaxAttempts, defaultMetadata)
-	}
-
-	if terragruntConfigFromFile.RetrySleepIntervalSec != nil {
-		terragruntConfig.RetrySleepIntervalSec = terragruntConfigFromFile.RetrySleepIntervalSec
-		terragruntConfig.SetFieldMetadata(MetadataRetrySleepIntervalSec, defaultMetadata)
-	}
-
 	if terragruntConfigFromFile.DownloadDir != nil {
 		terragruntConfig.DownloadDir = *terragruntConfigFromFile.DownloadDir
 		terragruntConfig.SetFieldMetadata(MetadataDownloadDir, defaultMetadata)
@@ -1707,11 +1663,6 @@ func convertToTerragruntConfig(ctx *ParsingContext, configPath string, terragrun
 		terragruntConfig.SetFieldMetadata(MetadataPreventDestroy, defaultMetadata)
 	}
 
-	if terragruntConfigFromFile.Skip != nil {
-		terragruntConfig.Skip = terragruntConfigFromFile.Skip
-		terragruntConfig.SetFieldMetadata(MetadataSkip, defaultMetadata)
-	}
-
 	if terragruntConfigFromFile.IamRole != nil {
 		terragruntConfig.IamRole = *terragruntConfigFromFile.IamRole
 		terragruntConfig.SetFieldMetadata(MetadataIamRole, defaultMetadata)
@@ -2038,12 +1989,21 @@ func (cfg *TerragruntConfig) ErrorsConfig() (*options.ErrorsConfig, error) {
 			continue
 		}
 
+		// Validate retry settings
+		if retryBlock.MaxAttempts < 1 {
+			return nil, errors.Errorf("cannot have less than 1 max retry in errors.retry %q, but you specified %d", retryBlock.Label, retryBlock.MaxAttempts)
+		}
+
+		if retryBlock.SleepIntervalSec < 0 {
+			return nil, errors.Errorf("cannot sleep for less than 0 seconds in errors.retry %q, but you specified %d", retryBlock.Label, retryBlock.SleepIntervalSec)
+		}
+
 		compiledPatterns := make([]*options.ErrorsPattern, 0, len(retryBlock.RetryableErrors))
 
 		for _, pattern := range retryBlock.RetryableErrors {
 			value, err := errorsPattern(pattern)
 			if err != nil {
-				return nil, fmt.Errorf("invalid retry pattern %q in block %q: %w",
+				return nil, errors.Errorf("invalid retry pattern %q in block %q: %w",
 					pattern, retryBlock.Label, err)
 			}
 
@@ -2082,7 +2042,7 @@ func (cfg *TerragruntConfig) ErrorsConfig() (*options.ErrorsConfig, error) {
 		for _, pattern := range ignoreBlock.IgnorableErrors {
 			value, err := errorsPattern(pattern)
 			if err != nil {
-				return nil, fmt.Errorf("invalid ignore pattern %q in block %q: %w",
+				return nil, errors.Errorf("invalid ignore pattern %q in block %q: %w",
 					pattern, ignoreBlock.Label, err)
 			}
 
